Proteases
=========

The proteases module provides lookups for common proteases and their cleavage patterns.



.. automodule:: tacular.proteases
   :members:
   :undoc-members:
   :show-inheritance:
